DieHistogram class
Dta structure that holds a histogram for a die
Constructors
-
DieHistogram({required List<
int> history}) - constructor
Properties
- five → int
-
How many 5s were there?
no setter
- four → int
-
How many 4s were there?
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- one → int
-
How many 1s were there?
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- six → int
-
How many 6s were there?
no setter
- three → int
-
How many 3s were there?
no setter
- two → int
-
How many 2s were there?
no setter
Methods
-
getFace(
int face) → int - get face frequency by value
-
getFacePercentage(
int face) → double - get face frequency percentage by value
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited