Puck class

This class simulates a craps puck

Constructors

Puck({bool state = false, bool crapless = false})
constructor

Properties

crapless bool
This flag shows whether or not the puck should obey craplless rules
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
off bool
convenience function for puck state
no setter
on bool
convenience function for puck state
no setter
point int
Returns the current point or 0 if puck is off
no setter
pointStr String
Get point as a String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state bool
This determines if the puck is on (true) or off (false)
getter/setter pair

Methods

evalRoll(int roll) → void
manage the puck based upon the roll
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pointMade() → void
Point made turn the puck off
pointSet(int point) → void
set the point
reset() → void
force reset the puck to off
sevenOut() → void
Seven out turn the puck off
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited