RollResult class

This holds the results of the roll of dice

Annotations
  • @immutable

Constructors

RollResult({required int firstDie, required int secondDie, bool isCrapless = false})
Constructor

Properties

firstDie int
holds the value of the first die
final
hashCode int
The hash code for this object.
no setteroverride
isCrapless bool
determines if the roll shoold be evaluated against a crapless table
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondDie int
holds the value of the seocnd die
final
value int
returns the result of the roll
no setter

Methods

isHard() bool
returns true if the roll is a hardway
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override