Die class
This is a die with ability to roll a random value and record history
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- histogram → DieHistogram
-
return a histogram of the die's roll history
no setter
-
history
→ List<
int> -
history of the rolls for this die
read-only
no setter
- name → String
-
Name for the die
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
roll(
) → int - Roll this die
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited